"""
GEO_search_atacseq_datasets

Search NCBI GEO for ATAC-seq chromatin accessibility datasets by query keyword, tissue, or cell t...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def GEO_search_atacseq_datasets(
    query: Optional[str | Any] = None,
    organism: Optional[str] = "Homo sapiens",
    limit: Optional[int] = 20,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search NCBI GEO for ATAC-seq chromatin accessibility datasets by query keyword, tissue, or cell t...

    Parameters
    ----------
    query : str | Any
        Search query (e.g., 'T cell differentiation', 'liver hepatocyte', 'hematopoie...
    organism : str
        Organism scientific name (e.g., 'Homo sapiens', 'Mus musculus').
    limit : int
        Maximum number of results to return (1-100).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {"query": query, "organism": organism, "limit": limit}.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "GEO_search_atacseq_datasets",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["GEO_search_atacseq_datasets"]
